Module: PartitionGardener::Strategy::RequiresDefaultPartition
- Included in:
- DateRange, HashBranches, IntegerRange, ListSplit
- Defined in:
- lib/partition_gardener/strategy/requires_default_partition.rb
Instance Method Summary collapse
-
#default_partition_drain_where_condition(window: active_window) ⇒ Object
Rows moved out of default at the end of maintenance (target: empty default).
- #default_partition_required? ⇒ Boolean
-
#rebalance_default_drain_where_condition(window: active_window) ⇒ Object
Rows in default matching this condition are staged during tail rebalance.
Instance Method Details
#default_partition_drain_where_condition(window: active_window) ⇒ Object
Rows moved out of default at the end of maintenance (target: empty default).
14 15 16 |
# File 'lib/partition_gardener/strategy/requires_default_partition.rb', line 14 def default_partition_drain_where_condition(window: active_window) current_and_future_where_condition(window: window) end |
#default_partition_required? ⇒ Boolean
4 5 6 |
# File 'lib/partition_gardener/strategy/requires_default_partition.rb', line 4 def default_partition_required? true end |
#rebalance_default_drain_where_condition(window: active_window) ⇒ Object
Rows in default matching this condition are staged during tail rebalance.
9 10 11 |
# File 'lib/partition_gardener/strategy/requires_default_partition.rb', line 9 def rebalance_default_drain_where_condition(window: active_window) current_and_future_where_condition(window: window) end |